@@ -9,7 +9,7 @@
 
 
 setMethod('aggregate', signature(x='Raster'), 
-function(x, fact=2, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
+function(x, fact, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
 
 
 	fact <- round(fact)
@@ -92,7 +92,7 @@ function(x, fact=2, fun='mean', expand=TRUE, na.rm=TRUE, filename="", ...)  {
 	}	
 
 	fun <- .makeTextFun(fun)
-	if (class(fun)[1] == 'character') { 
+	if (inherits(fun, 'character')) { 
 		op <- as.integer(match(fun, c('sum', 'mean', 'min', 'max')) - 1)
 	} else {
 		op <- NA
