@@ -4,10 +4,6 @@
 # Licence GPL v3
  
 
-if (!isGeneric("boxplot")) {
-	setGeneric("boxplot", function(x, ...)
-		standardGeneric("boxplot"))
-}
 
 setMethod('boxplot', signature(x='RasterStackBrick'), 
 	function(x, maxpixels=100000, ...) {
@@ -51,7 +47,7 @@ setMethod('boxplot', signature(x='RasterLayer'),
 				cn <- c('layer1', 'layer2')
 				colnames(s) <- cn
 			}
-			f <- as.formula(paste(cn[1], '~', cn[2]))
+			f <- stats::as.formula(paste(cn[1], '~', cn[2]))
 			boxplot(f, data=s, ...)
 		}	
 	}
