@@ -11,7 +11,7 @@ drawPoly <- function(sp=TRUE, col='red', lwd=2, ...) {
 	xy <- rbind(xy, xy[1,])
 	lines(xy[(length(xy[,1])-1):length(xy[,1]),], col=col, lwd=lwd, ...)
 	if (sp) {
-		return( SpatialPolygons(list(Polygons(list(Polygon(xy)), 1))) )
+		return( sp::SpatialPolygons(list(sp::Polygons(list(sp::Polygon(xy)), 1))) )
 	} else {
 		return(xy)
 	}
@@ -22,7 +22,7 @@ drawLine <- function(sp=TRUE, col='red', lwd=2, ...) {
 	xy <- graphics::locator(n=10000, type="l", col=col, lwd=lwd, ...)
 	xy <- cbind(xy$x, xy$y)
 	if (sp) {
-		return( SpatialLines(list(Lines(list(Line(xy)), "1"))) )
+		return( sp::SpatialLines(list(sp::Lines(list(sp::Line(xy)), "1"))) )
 	} else {
 		return(xy)
 	}
