@@ -12,22 +12,21 @@ setMethod('raster', signature(x='missing'),
 		}
 		if (missing(crs)) {
 			if (ext@xmin > -360.01 & ext@xmax < 360.01 & ext@ymin > -90.01 & ext@ymax < 90.01) { 
-				crs <- CRS("+proj=longlat +datum=WGS84")
+				crs <- .spCRS("+proj=longlat +datum=WGS84")
 			} else {
-				# if sp >= 1.2.1  crs <- CRS(as.character(NA), doCheckCRSArgs=FALSE)
-				crs <- CRS(as.character(NA), doCheckCRSArgs=FALSE)
+				# if sp >= 1.2.1  crs <- .spCRS(as.character(NA), doCheckCRSArgs=FALSE)
+				crs <- .spCRS(as.character(NA), doCheckCRSArgs=FALSE)
 			}
-		} else {
-			crs <- .getCRS(crs)
-		}
+		} 
 		if (missing(resolution)) {
 			nrows <- as.integer(max(1, round(nrows)))
 			ncols <- as.integer(max(1, round(ncols)))
-			r <- methods::new('RasterLayer', extent=ext, nrows=nrows, ncols=ncols, crs=crs)
+			r <- methods::new('RasterLayer', extent=ext, nrows=nrows, ncols=ncols)
 		} else {
-			r <- methods::new('RasterLayer', extent=ext, crs=crs)
+			r <- methods::new('RasterLayer', extent=ext)
 			res(r) <- resolution
 		}
+		projection(r) <- crs
 		if (!is.null(vals)) {
 			return( setValues(r, vals) )
 		} else {
@@ -66,9 +65,9 @@ setMethod('raster', signature(x='list'),
 		
 		if (missing(crs)) {
 			if (xmn > -360.1 & xmx < 360.1 & ymn > -90.1 & ymx < 90.1) { 
-				crs <- CRS("+proj=longlat +datum=WGS84")
+				crs <- .spCRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- CRS(as.character(NA))
+				crs <- .spCRS(as.character(NA))
 			}
 		} else {
 			crs <- .getCRS(crs)
@@ -224,6 +223,7 @@ setMethod('raster', signature(x='RasterBrick'),
 
 				r@file@blockrows <- x@file@blockrows
 				r@file@blockcols <- x@file@blockcols
+				r@file@nbands <- nlayers(x)
 				
 				r@data@offset <- x@data@offset
 				r@data@gain <- x@data@gain
@@ -289,7 +289,7 @@ setMethod('raster', signature(x='RasterBrick'),
 setMethod('raster', signature(x='Extent'), 
 	function(x, nrows=10, ncols=10, crs="", ...) {
 		crs <- .getCRS(crs)
-		raster(xmn=x@xmin, xmx=x@xmax, ymn=x@ymin, ymx=x@ymax, ncols=ncols, nrows=nrows, crs=crs, ...)
+		raster(ncols=ncols, nrows=nrows, ext=x, crs=crs, ...)
 	}
 )
 
@@ -384,7 +384,7 @@ setMethod('raster', signature(x='im'),
 	function(x, crs) {
 		r <- as(x, 'RasterLayer')
 		if (!missing(crs)) {
-			projection(r) <- crs
+			projection(r) <- .spCRS()
 		}
 		r
 	}
@@ -398,7 +398,7 @@ setMethod('raster', signature(x='kasc'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- CRS("+proj=longlat +datum=WGS84")
+				crs <- .spCRS("+proj=longlat +datum=WGS84")
 			} else {
 				crs <- as.character(NA)
 			}
@@ -416,9 +416,9 @@ setMethod('raster', signature(x='asc'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- CRS("+proj=longlat +datum=WGS84")
+				crs <- .spCRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- CRS(as.character(NA))
+				crs <- .spCRS(as.character(NA))
 			}
 		}
 		projection(x) <- crs
@@ -433,9 +433,9 @@ setMethod('raster', signature(x='kde'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- CRS("+proj=longlat +datum=WGS84")
+				crs <- .spCRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- CRS(as.character(NA))
+				crs <- .spCRS(as.character(NA))
 			}
 		}
 		projection(x) <- crs
@@ -472,6 +472,8 @@ setMethod('raster', signature(x='GridTopology'),
 
 setMethod('raster', signature(x='SpatRaster'),
 	function(x) {
-		as(x[[1]], "Raster")
+		r <- as(x[[1]], "Raster")
+		g <- gc()
+		r
 	}
 )
